@@ -260,6 +260,8 @@ pub enum RuinMethod {
     /// Close route removal method.
     #[serde(rename(deserialize = "close-route"))]
     CloseRoute { probability: f64 },
+    #[serde(rename(deserialize = "worst-route"))]
+    WorstRoute { probability: f64 },
     /// Random ruin removal method.
     #[serde(rename(deserialize = "random-ruin"))]
     RandomRuin { probability: f64 },
@@ -431,7 +433,7 @@ fn configure_from_evolution(
     mut builder: ProblemConfigBuilder,
     problem: Arc<Problem>,
     environment: Arc<Environment>,
-    telemetry_config: &Option<TelemetryConfig>,
+    telemetry_mode: TelemetryMode,
     population_config: &Option<EvolutionConfig>,
 ) -> Result<ProblemConfigBuilder, String> {
     if let Some(config) = population_config {
@@ -524,8 +526,6 @@ fn configure_from_evolution(
                 }
             };
 
-            let telemetry_mode = get_telemetry_mode(environment.clone(), telemetry_config);
-
             builder = builder.with_context(RefinementContext::new(problem, population, telemetry_mode, environment));
         }
     }
@@ -701,6 +701,7 @@ fn create_ruin_method(
             *probability,
         ),
         RuinMethod::CloseRoute { probability } => (Arc::new(CloseRouteRemoval::default()), *probability),
+        RuinMethod::WorstRoute { probability } => (Arc::new(WorstRouteRemoval::default()), *probability),
         RuinMethod::RandomRuin { probability } => (create_default_random_ruin(), *probability),
     }
 }
@@ -823,11 +824,12 @@ pub fn create_builder_from_config(
 ) -> Result<ProblemConfigBuilder, String> {
     let environment =
         configure_from_environment(&config.environment, config.termination.as_ref().and_then(|t| t.max_time));
-    let mut builder =
-        create_default_config_builder(problem.clone(), environment.clone()).with_init_solutions(solutions, None);
+    let telemetry_mode = get_telemetry_mode(environment.clone(), &config.telemetry);
+    let mut builder = create_default_config_builder(problem.clone(), environment.clone(), telemetry_mode.clone())
+        .with_init_solutions(solutions, None);
 
     builder =
-        configure_from_evolution(builder, problem.clone(), environment.clone(), &config.telemetry, &config.evolution)?;
+        configure_from_evolution(builder, problem.clone(), environment.clone(), telemetry_mode, &config.evolution)?;
     builder = configure_from_hyper(builder, problem, environment, &config.hyper)?;
     builder = configure_from_termination(builder, &config.termination);
 
