@@ -1,5 +1,6 @@
 use super::*;
 use std::fs::File;
+use vrp_core::models::examples::create_example_problem;
 
 #[test]
 fn can_read_full_config() {
@@ -88,7 +89,7 @@ fn can_read_full_config() {
             match operators.get(2).unwrap() {
                 SearchOperatorType::RuinRecreate { probability, ruins, recreates } => {
                     assert_eq!(as_scalar_probability(probability), 1.);
-                    assert_eq!(ruins.len(), 6);
+                    assert_eq!(ruins.len(), 7);
                     assert_eq!(recreates.len(), 12);
                 }
                 _ => unreachable!(),
@@ -132,6 +133,30 @@ fn can_create_default_config() {
     assert!(config.telemetry.is_none());
 }
 
+#[test]
+fn can_configure_telemetry_metrics() {
+    let config = Config {
+        evolution: None,
+        hyper: None,
+        termination: Some(TerminationConfig { max_time: None, max_generations: Some(100), variation: None }),
+        environment: None,
+        telemetry: Some(TelemetryConfig {
+            progress: None,
+            metrics: Some(MetricsConfig { enabled: true, track_population: Some(10) }),
+        }),
+    };
+
+    let (_, _, metrics) = create_builder_from_config(create_example_problem(), Vec::default(), &config)
+        .and_then(|config_builder| config_builder.build())
+        .map(|evolution_config| Solver::new(create_example_problem(), evolution_config))
+        .and_then(|solver| solver.solve())
+        .unwrap();
+
+    let metrics = metrics.expect("no metrics");
+    assert_eq!(metrics.generations, 100);
+    assert_eq!(metrics.evolution.len(), 10 + 1);
+}
+
 fn as_scalar_probability(probability: &OperatorProbabilityType) -> f64 {
     match probability {
         OperatorProbabilityType::Scalar { scalar } => *scalar,
